@@ -106,12 +106,34 @@ class GenomeViz:
         if err_msg:
             raise ValueError(err_msg)
 
+    def _get_track_offset(self, track: Track) -> int:
+        """Get track offset
+
+        Parameters
+        ----------
+        track : Track
+            Target track offset for alignment
+
+        Returns
+        -------
+        track_offset : int
+            Track offset
+        """
+        if self.align_type == "left":
+            return 0
+        elif self.align_type == "center":
+            return int((self.max_track_size - track.size) / 2)
+        elif self.align_type == "right":
+            return self.max_track_size - track.size
+        else:
+            raise NotImplementedError()
+
     @property
     def _track_name2offset(self) -> Dict[str, int]:
         """Track name & offset dict"""
         track_name2offset = {}
         for track in self.get_tracks(subtrack=True):
-            track_name2offset[track.name] = self.get_track_offset(track)
+            track_name2offset[track.name] = self._get_track_offset(track)
         return track_name2offset
 
     def _get_link_track(
@@ -202,9 +224,18 @@ class GenomeViz:
         feature_track_name: str,
         subtrack_name: str,
         ratio: float = 1.0,
-        type: str = "blank",
     ) -> None:
-        """Add feature subtrack"""
+        """Add subtrack of feature track
+
+        Parameters
+        ----------
+        feature_track_name : str
+            Feature track name to be added subtrack
+        subtrack_name : str
+            Subtrack name
+        ratio : float, optional
+            Subtrack size ratio to feature track
+        """
         feature_track = self.get_track(feature_track_name)
         if not isinstance(feature_track, FeatureTrack):
             err_msg = f"'{feature_track_name}' is not FeatureTrack."
@@ -227,6 +258,7 @@ class GenomeViz:
         interpolation_value: Optional[float] = None,
         vmin: float = 0,
         vmax: float = 100,
+        curve: bool = False,
     ) -> None:
         """Add link data to link track
 
@@ -246,6 +278,8 @@ class GenomeViz:
             Min value for color interpolation
         vmax : float, optional
             Max value for color interpolation
+        curve : bool, optional
+            If True, bezier curve link is plotted
         """
         link_track = self._get_link_track(track_link1[0], track_link2[0])
         tracks = [t.name for t in self.get_tracks()]
@@ -268,6 +302,7 @@ class GenomeViz:
                 interpolation_value,
                 vmin,
                 vmax,
+                curve,
             )
         )
 
@@ -332,30 +367,13 @@ class GenomeViz:
             raise ValueError(err_msg)
         return max([track.size for track in self.get_tracks()])
 
-    def get_track_offset(self, track: Track) -> int:
-        """Get track offset
+    def plotfig(self, dpi: int = 300) -> Figure:
+        """Plot figure
 
         Parameters
         ----------
-        track : Track
-            Target track offset for alignment
-
-        Returns
-        -------
-        track_offset : int
-            Track offset
-        """
-        if self.align_type == "left":
-            return 0
-        elif self.align_type == "center":
-            return int((self.max_track_size - track.size) / 2)
-        elif self.align_type == "right":
-            return self.max_track_size - track.size
-        else:
-            raise NotImplementedError()
-
-    def plotfig(self) -> Figure:
-        """Plot figure
+        dpi : int, optional
+            DPI
 
         Returns
         -------
@@ -378,7 +396,7 @@ class GenomeViz:
 
         track_num = len(self.get_tracks(subtrack=True))
         figsize = (self.fig_width, self.fig_track_height * track_num)
-        figure: Figure = plt.figure(figsize=figsize, facecolor="white")
+        figure: Figure = plt.figure(figsize=figsize, facecolor="white", dpi=dpi)
 
         track_ratios = [t.ratio for t in self.get_tracks(subtrack=True)]
         spec = gridspec.GridSpec(
@@ -390,7 +408,8 @@ class GenomeViz:
             ax: Axes = figure.add_subplot(
                 spec[idx], xlim=xlim, ylim=ylim, fc="none", zorder=track.zorder
             )
-            track._ax = ax
+            track_offset = self._get_track_offset(track)
+            track._ax, track._offset = ax, track_offset
             # Set 'spines' and 'ticks' visibility
             for spine, display in track.spines_params.items():
                 ax.spines[spine].set_visible(display)
@@ -401,7 +420,6 @@ class GenomeViz:
                 if track.labelsize != 0:
                     ax.text(-self.max_track_size * 0.01, 0, **track.label_params)
                 # Plot track scale line
-                track_offset = self.get_track_offset(track)
                 xmin, xmax = track_offset, track.size + track_offset
                 ax.hlines(0, xmin, xmax, "black", linewidth=track.linewidth)
 
@@ -422,7 +440,7 @@ class GenomeViz:
                         ax.text(**feature.text_params(ylim, self.feature_size_ratio))
 
             if isinstance(track, FeatureSubTrack):
-                # TODO: Add GC content & GC skew plot function
+                # No specific plans to implementation at this time
                 pass
 
             elif isinstance(track, LinkTrack):
@@ -430,8 +448,8 @@ class GenomeViz:
                     link = link.add_offset(self._track_name2offset)
                     link_ymin = ylim[0] * self.link_size_ratio
                     link_ymax = ylim[1] * self.link_size_ratio
-                    xy = link.polygon_xy(link_ymin, link_ymax)
-                    p = patches.Polygon(xy=xy, fc=link.color, ec=link.color)
+                    path = link.path(link_ymin, link_ymax)
+                    p = patches.PathPatch(path, fc=link.color, ec=link.color)
                     ax.add_patch(p)
 
             elif isinstance(track, TickTrack):
@@ -440,9 +458,10 @@ class GenomeViz:
                     ax.xaxis.set_major_formatter(track.tick_formatter)
                 elif self.tick_style == "bar":
                     ymin, ycenter, ymax = track.ymin, track.ycenter, track.ymax
-                    ax.hlines(ycenter, track.xmin, track.xmax, "black", linewidth=1)
-                    ax.vlines(track.xmin, ymin, ymax, "black", linewidth=1)
-                    ax.vlines(track.xmax, ymin, ymax, "black", linewidth=1)
+                    common_opts = {"colors": "black", "linewidth": 1, "clip_on": False}
+                    ax.hlines(ycenter, track.xmin, track.xmax, **common_opts)
+                    ax.vlines(track.xmin, ymin, ymax, **common_opts)
+                    ax.vlines(track.xmax, ymin, ymax, **common_opts)
                     ax.text(**track.scalebar_text_params)
 
         return figure
@@ -464,10 +483,10 @@ class GenomeViz:
         pad_inches : float, optional
             Padding inches
         """
-        figure = self.plotfig()
+        figure = self.plotfig(dpi=dpi)
         figure.savefig(
             fname=savefile,
-            dpi=dpi,
+            dpi="figure",
             pad_inches=pad_inches,
             bbox_inches="tight",
         )
